@@ -33,7 +33,7 @@ from .pooling import (
 )
 
 
-class BaseDatabaseConfig(
+class BaseConfig(
     BaseModel, Generic[ConnectionConfigT, PoolingConfigT, AdditionalConfigT]
 ):
     """Base configuration for database."""
@@ -44,8 +44,8 @@ class BaseDatabaseConfig(
     additional: AdditionalConfigT = Field(..., description="Additional config")
 
 
-class MySQLDatabaseConfig(
-    BaseDatabaseConfig[
+class MySQLConfig(
+    BaseConfig[
         MySQLConnectionConfig,
         MySQLPoolingConfig,
         None,
@@ -72,8 +72,8 @@ class MySQLDatabaseConfig(
             return create_sync_engine(url, **self.engine_kwargs)
 
 
-class PostgreSQLDatabaseConfig(
-    BaseDatabaseConfig[
+class PostgreSQLConfig(
+    BaseConfig[
         PostgreSQLConnectionConfig,
         PostgreSQLPoolingConfig,
         None,
@@ -100,8 +100,8 @@ class PostgreSQLDatabaseConfig(
             return create_sync_engine(url, **self.engine_kwargs)
 
 
-class SQLiteDatabaseConfig(
-    BaseDatabaseConfig[
+class SQLiteConfig(
+    BaseConfig[
         SQLiteConnectionConfig,
         SQLitePoolingConfig,
         None,
@@ -128,8 +128,8 @@ class SQLiteDatabaseConfig(
             return create_sync_engine(url, **self.engine_kwargs)
 
 
-class SQLServerDatabaseConfig(
-    BaseDatabaseConfig[
+class SQLServerConfig(
+    BaseConfig[
         SQLServerConnectionConfig,
         SQLServerPoolingConfig,
         None,
@@ -158,15 +158,15 @@ class SQLServerDatabaseConfig(
 
 SQLConfigT = TypeVar(
     "SQLConfigT",
-    PostgreSQLDatabaseConfig,
-    MySQLDatabaseConfig,
-    SQLiteDatabaseConfig,
-    SQLServerDatabaseConfig,
+    PostgreSQLConfig,
+    MySQLConfig,
+    SQLiteConfig,
+    SQLServerConfig,
 )
 
 
-class ElasticsearchDatabaseConfig(
-    BaseDatabaseConfig[
+class ElasticsearchConfig(
+    BaseConfig[
         ElasticsearchConnectionConfig,
         ElasticsearchPoolingConfig,
         None,
@@ -204,8 +204,8 @@ class ElasticsearchDatabaseConfig(
             return Elasticsearch(hosts, **self.client_kwargs)
 
 
-class MongoDBDatabaseConfig(
-    BaseDatabaseConfig[
+class MongoDBConfig(
+    BaseConfig[
         MongoDBConnectionConfig,
         MongoDBPoolingConfig,
         None,
@@ -233,8 +233,8 @@ class MongoDBDatabaseConfig(
             return MongoClient(url, **self.client_kwargs)
 
 
-class RedisDatabaseConfig(
-    BaseDatabaseConfig[
+class RedisConfig(
+    BaseConfig[
         RedisConnectionConfig,
         RedisPoolingConfig,
         RedisAdditionalConfig,
@@ -260,19 +260,31 @@ class RedisDatabaseConfig(
 
 NoSQLConfigT = TypeVar(
     "NoSQLConfigT",
-    ElasticsearchDatabaseConfig,
-    MongoDBDatabaseConfig,
-    RedisDatabaseConfig,
+    ElasticsearchConfig,
+    MongoDBConfig,
+    RedisConfig,
 )
 
 
-ConfigT = TypeVar(
-    "ConfigT",
-    PostgreSQLDatabaseConfig,
-    MySQLDatabaseConfig,
-    SQLiteDatabaseConfig,
-    SQLServerDatabaseConfig,
-    MongoDBDatabaseConfig,
-    RedisDatabaseConfig,
-    ElasticsearchDatabaseConfig,
+DatabaseConfigT = TypeVar(
+    "DatabaseConfigT",
+    PostgreSQLConfig,
+    MySQLConfig,
+    SQLiteConfig,
+    SQLServerConfig,
+    MongoDBConfig,
+    RedisConfig,
+    ElasticsearchConfig,
 )
+
+
+# * This class is left empty to be overridden in the future when defining configuration
+class Config(BaseModel):
+    pass
+
+
+ConfigT = TypeVar("ConfigT", bound=Config)
+
+
+class ConfigMixin(BaseModel, Generic[ConfigT]):
+    database: ConfigT = Field(..., description="Databases config")
