@@ -3,21 +3,7 @@ from typing import Optional, TypeVar, Union
 from maleo.enums.cache import Origin, Layer
 from maleo.enums.expiration import Expiration
 from maleo.types.base.string import OptionalString
-
-
-class RedisCacheNamespaces(BaseModel):
-    base: str = Field(..., description="Base Redis's namespace")
-
-    def create(
-        self,
-        *ext: str,
-        origin: Origin,
-        layer: Layer,
-        base_override: OptionalString = None,
-    ) -> str:
-        return ":".join(
-            [self.base if base_override is None else base_override, origin, layer, *ext]
-        )
+from maleo.utils.cache import build_namespace as build_namespace_utils
 
 
 class BaseAdditionalConfig(BaseModel):
@@ -31,6 +17,18 @@ class RedisAdditionalConfig(BaseAdditionalConfig):
     ttl: Union[float, int] = Field(
         Expiration.EXP_15MN.value, description="Time to live"
     )
-    namespaces: RedisCacheNamespaces = Field(
-        ..., description="Redis cache's namepsaces"
-    )
+    base_namespace: str = Field(..., description="Base namespace")
+
+    def build_namespace(
+        self,
+        *ext: str,
+        base: OptionalString = None,
+        client: OptionalString = None,
+        origin: Origin,
+        layer: Layer,
+        sep: str = ":",
+    ) -> str:
+        base = base or self.base_namespace
+        return build_namespace_utils(
+            *ext, base=base, client=client, origin=origin, layer=layer, sep=sep
+        )
