@@ -31,14 +31,14 @@ from maleo.schemas.operation.system import (
 from maleo.schemas.response import NoDataResponse
 from maleo.types.base.uuid import OptionalUUID
 from ..config import (
-    MySQLDatabaseConfig,
-    PostgreSQLDatabaseConfig,
-    SQLiteDatabaseConfig,
-    SQLServerDatabaseConfig,
+    MySQLConfig,
+    PostgreSQLConfig,
+    SQLiteConfig,
+    SQLServerConfig,
     SQLConfigT,
-    ElasticsearchDatabaseConfig,
-    MongoDBDatabaseConfig,
-    RedisDatabaseConfig,
+    ElasticsearchConfig,
+    MongoDBConfig,
+    RedisConfig,
     NoSQLConfigT,
     ConfigT,
 )
@@ -251,19 +251,19 @@ class SQLDatabaseManager(DatabaseManager[SQLConfigT], Generic[SQLConfigT]):
         await self._engine_manager.dispose()
 
 
-class MySQLDatabaseManager(SQLDatabaseManager[MySQLDatabaseConfig]):
+class MySQLDatabaseManager(SQLDatabaseManager[MySQLConfig]):
     pass
 
 
-class PostgreSQLDatabaseManager(SQLDatabaseManager[PostgreSQLDatabaseConfig]):
+class PostgreSQLDatabaseManager(SQLDatabaseManager[PostgreSQLConfig]):
     pass
 
 
-class SQLiteDatabaseManager(SQLDatabaseManager[SQLiteDatabaseConfig]):
+class SQLiteDatabaseManager(SQLDatabaseManager[SQLiteConfig]):
     pass
 
 
-class SQLServerDatabaseManager(SQLDatabaseManager[SQLServerDatabaseConfig]):
+class SQLServerDatabaseManager(SQLDatabaseManager[SQLServerConfig]):
     pass
 
 
@@ -361,20 +361,18 @@ class NoSQLDatabaseManager(
 
 
 class ElasticsearchDatabaseManager(
-    NoSQLDatabaseManager[ElasticsearchDatabaseConfig, AsyncElasticsearch, Elasticsearch]
+    NoSQLDatabaseManager[ElasticsearchConfig, AsyncElasticsearch, Elasticsearch]
 ):
     pass
 
 
 class MongoDBDatabaseManager(
-    NoSQLDatabaseManager[MongoDBDatabaseConfig, AsyncIOMotorClient, MongoClient]
+    NoSQLDatabaseManager[MongoDBConfig, AsyncIOMotorClient, MongoClient]
 ):
     pass
 
 
-class RedisDatabaseManager(
-    NoSQLDatabaseManager[RedisDatabaseConfig, AsyncRedis, SyncRedis]
-):
+class RedisDatabaseManager(NoSQLDatabaseManager[RedisConfig, AsyncRedis, SyncRedis]):
     pass
 
 
