@@ -6,9 +6,9 @@ from redis import Redis as SyncRedis
 from typing import Generic, Literal, Optional, Tuple, TypeVar, Union, overload
 from maleo.types.base.string import ListOfStrings
 from ..config import (
-    ElasticsearchDatabaseConfig,
-    MongoDBDatabaseConfig,
-    RedisDatabaseConfig,
+    ElasticsearchConfig,
+    MongoDBConfig,
+    RedisConfig,
     NoSQLConfigT,
 )
 from ..enums import Connection
@@ -60,18 +60,18 @@ class ClientManager(
 
 
 class ElasticsearchClientManager(
-    ClientManager[ElasticsearchDatabaseConfig, AsyncElasticsearch, Elasticsearch]
+    ClientManager[ElasticsearchConfig, AsyncElasticsearch, Elasticsearch]
 ):
     pass
 
 
 class MongoDBClientManager(
-    ClientManager[MongoDBDatabaseConfig, AsyncIOMotorClient, MongoClient]
+    ClientManager[MongoDBConfig, AsyncIOMotorClient, MongoClient]
 ):
     pass
 
 
-class RedisClientManager(ClientManager[RedisDatabaseConfig, AsyncRedis, SyncRedis]):
+class RedisClientManager(ClientManager[RedisConfig, AsyncRedis, SyncRedis]):
     async def async_clear(self, prefixes: Optional[Union[ListOfStrings, str]] = None):
         if prefixes is None:
             prefixes = [self._config.additional.base_namespace]
